package com.ruoyi.model.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.model.mapper.AppPetTypeMapper;
import com.ruoyi.model.domain.AppPetType;
import com.ruoyi.model.service.IAppPetTypeService;

/**
 * 宠物类型Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@Service
public class AppPetTypeServiceImpl implements IAppPetTypeService 
{
    @Autowired
    private AppPetTypeMapper appPetTypeMapper;

    /**
     * 查询宠物类型
     * 
     * @param petTypeId 宠物类型主键
     * @return 宠物类型
     */
    @Override
    public AppPetType selectAppPetTypeByPetTypeId(Long petTypeId)
    {
        return appPetTypeMapper.selectAppPetTypeByPetTypeId(petTypeId);
    }

    /**
     * 查询宠物类型列表
     * 
     * @param appPetType 宠物类型
     * @return 宠物类型
     */
    @Override
    public List<AppPetType> selectAppPetTypeList(AppPetType appPetType)
    {
        return appPetTypeMapper.selectAppPetTypeList(appPetType);
    }

    /**
     * 新增宠物类型
     * 
     * @param appPetType 宠物类型
     * @return 结果
     */
    @Override
    public int insertAppPetType(AppPetType appPetType)
    {
        return appPetTypeMapper.insertAppPetType(appPetType);
    }

    /**
     * 修改宠物类型
     * 
     * @param appPetType 宠物类型
     * @return 结果
     */
    @Override
    public int updateAppPetType(AppPetType appPetType)
    {
        return appPetTypeMapper.updateAppPetType(appPetType);
    }

    /**
     * 批量删除宠物类型
     * 
     * @param petTypeIds 需要删除的宠物类型主键
     * @return 结果
     */
    @Override
    public int deleteAppPetTypeByPetTypeIds(Long[] petTypeIds)
    {
        return appPetTypeMapper.deleteAppPetTypeByPetTypeIds(petTypeIds);
    }

    /**
     * 删除宠物类型信息
     * 
     * @param petTypeId 宠物类型主键
     * @return 结果
     */
    @Override
    public int deleteAppPetTypeByPetTypeId(Long petTypeId)
    {
        return appPetTypeMapper.deleteAppPetTypeByPetTypeId(petTypeId);
    }

    /**
     * 查询宠物类型列表
     *
     * @return 宠物类型集合
     */
    @Override
    public List<AppPetType> getAppPetTypeList(){
        return appPetTypeMapper.getAppPetTypeList();
    }
}
